# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/github.com/tendermint/tendermint/crypto/merkle/merkle.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protobuf.github.com.gogo.protobuf.gogoproto import gogo_pb2 as protobuf_dot_github_dot_com_dot_gogo_dot_protobuf_dot_gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/github.com/tendermint/tendermint/crypto/merkle/merkle.proto',
  package='merkle',
  syntax='proto3',
  serialized_pb=_b('\nDprotobuf/github.com/tendermint/tendermint/crypto/merkle/merkle.proto\x12\x06merkle\x1a\x36protobuf/github.com/gogo/protobuf/gogoproto/gogo.proto\"2\n\x07ProofOp\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"+\n\x05Proof\x12\"\n\x03ops\x18\x01 \x03(\x0b\x32\x0f.merkle.ProofOpB\x04\xc8\xde\x1f\x00\x42\x14\xc8\xe2\x1e\x01\xd0\xe2\x1e\x01\xe0\xe2\x1e\x01\xf8\xe1\x1e\x01\xa8\xe2\x1e\x01\x62\x06proto3')
  ,
  dependencies=[protobuf_dot_github_dot_com_dot_gogo_dot_protobuf_dot_gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_PROOFOP = _descriptor.Descriptor(
  name='ProofOp',
  full_name='merkle.ProofOp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='merkle.ProofOp.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='merkle.ProofOp.key', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='merkle.ProofOp.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=186,
)


_PROOF = _descriptor.Descriptor(
  name='Proof',
  full_name='merkle.Proof',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ops', full_name='merkle.Proof.ops', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\310\336\037\000')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=231,
)

_PROOF.fields_by_name['ops'].message_type = _PROOFOP
DESCRIPTOR.message_types_by_name['ProofOp'] = _PROOFOP
DESCRIPTOR.message_types_by_name['Proof'] = _PROOF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProofOp = _reflection.GeneratedProtocolMessageType('ProofOp', (_message.Message,), dict(
  DESCRIPTOR = _PROOFOP,
  __module__ = 'protobuf.github.com.tendermint.tendermint.crypto.merkle.merkle_pb2'
  # @@protoc_insertion_point(class_scope:merkle.ProofOp)
  ))
_sym_db.RegisterMessage(ProofOp)

Proof = _reflection.GeneratedProtocolMessageType('Proof', (_message.Message,), dict(
  DESCRIPTOR = _PROOF,
  __module__ = 'protobuf.github.com.tendermint.tendermint.crypto.merkle.merkle_pb2'
  # @@protoc_insertion_point(class_scope:merkle.Proof)
  ))
_sym_db.RegisterMessage(Proof)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\310\342\036\001\320\342\036\001\340\342\036\001\370\341\036\001\250\342\036\001'))
_PROOF.fields_by_name['ops'].has_options = True
_PROOF.fields_by_name['ops']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\310\336\037\000'))
# @@protoc_insertion_point(module_scope)
